API for Tags
===============

.. module:: digikamdb.tags

The Tags Class
-----------------

.. autoclass:: Tags
   :members:

The Tag Class (mapped)
-------------------------

.. autoclass:: _sqla.Tag
   :members:

Tag Properties
-----------------

.. autoclass:: TagProperties
    :members:

.. ifconfig::   include_private_content
    
    .. autoclass::  _sqla.TagProperty
        :members:


